
FIRST_PART = [
    'Champ, ',
    'Fact, ',
    'Everybody says ',
    'Dang... ',
    'Check it: ',
    'Just saying... ',
    'Superstar, ',
    'Tiger, ',
    'Self, ',
    'Know this, ',
    'News alert, ',
    'Ace, ',
    'Excuse me but ',
    'Experts agree ',
    'In my opinion ',
    'Hear ye, hear ye: ',
    'Okay, listen up: ',
]

SECOND_PART = [
    'the mere idea of you ',
    'your soul ',
    'your hair today ',
    'everything you do ',
    'your personal style ',
    'every thought you have ',
    'your presence here ',
    'what you got going on ',
    'the essential you ',
    'your life\'s journey ',
    'that saucy personality ',
    'your DNA ',
    'that brain of yours ',
    'your choice of attire ',
    'the way you roll ',
    'whatever your secret is ',
    'all of y\'all ',
]

THIRD_PART = [
    'has serious game, ',
    'rains magic, ',
    'deserves the Nobel Prize, ',
    'raises the roof, ',
    'breeds miracles, ',
    'is paying off big time, ',
    'shows mad skills ',
    'just shimmers ',
    'is a national treasure ',
    'gets the party hopping, ',
    'is the next big thing, ',
    'roars like a lion, ',
    'is a rainbow factory, ',
    'is made of diamonds, ',
    'makes birds sing, ',
    'should be taught in schools, ',
    'makes my world go \'round, ',
    'is 100% legit ',
]

FOURTH_PART = [
    '24/7.',
    'can I get an amen?',
    'and that\'s a fact.',
    'so treat yourself.',
    'you feel me?',
    'that\'s just science',
    'would I lie?',
    'for reals.',
    'mic drop.',
    'you hidden gem.',
    'snuggle bear.',
    'period.',
    'now let\'s dance.',
    'high five.',
    'say it again!',
    'according to BBC',
    'so get used to it.',
]

PARTS = [
    FIRST_PART,
    SECOND_PART,
    THIRD_PART,
    FOURTH_PART,
]
